@@ -9,15 +9,15 @@ async def profiles(
     hub,
     acct_file: str = None,
     acct_key: str = None,
+    acct_data: Dict = None,
+    **kwargs,
 ) -> Dict[str, List[Dict[str, Any]]]:
     """
     Read the acct information from the named subs and return the context
     """
-    if acct_file and acct_key:
+    if acct_file and acct_data is None:
         hub.log.debug("Reading profiles from acct")
-        acct_data = await hub.acct.init.profiles(acct_file, acct_key)
-    else:
-        acct_data = {}
+        acct_data = await hub.acct.init.profiles(acct_file, acct_key, **kwargs)
 
     ret_data = data.NamespaceDict()
 
